==> 2.4.zip: piwigo/plugins/c13y_upgrade/language/ru_RU/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

// --------- Starting below: New or revised $lang ---- from Butterfly (1.8)
$lang['c13y_upgrade_no_anomaly'] = 'Аномалии не обнаружены после применения обновления. плагин "Проверить обновления" был отключен.';
$lang['c13y_dbl_email_user'] = 'Пользователи с тем же адресом электронной почты';
$lang['c13y_correction_dbl_email_user'] = 'Удаление дубликатов пользователей';
$lang['c13y_obsolete_plugin'] = 'Устаревший плагин';
$lang['c13y_correction_obsolete_plugin'] = 'Модуль "%s" отключена, потому что она не совместима с этой версией Piwigo . Пожалуйста, удалите его.';

?>

==> 2.5.zip: piwigo/plugins/c13y_upgrade/language/ru_RU/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

// --------- Starting below: New or revised $lang ---- from Butterfly (1.8)
$lang['c13y_upgrade_no_anomaly'] = 'Аномалии не обнаружены после применения обновления. Плагин "Проверить обновления" был отключен.';
$lang['c13y_dbl_email_user'] = 'Пользователи с тем же адресом электронной почты';
$lang['c13y_correction_dbl_email_user'] = 'Удаление дубликатов пользователей';
$lang['c13y_obsolete_plugin'] = 'Устаревший плагин';
$lang['c13y_correction_obsolete_plugin'] = 'Плагин "%s" отключен, потому что он не совместима с этой версией Piwigo. Пожалуйста, удалите этот плагин.';

?>
